@@ -199,18 +199,9 @@ use File::Glob qw(:case);
         'UPSTREAM'    => 'blead',
     },
 
-    'Archive::Extract' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Archive-Extract-0.68.tar.gz',
-        'FILES'        => q[cpan/Archive-Extract],
-        'UPSTREAM'     => 'cpan',
-        'BUGS'         => 'bug-archive-extract@rt.cpan.org',
-        'DEPRECATED'   => '5.017009',
-    },
-
     'Archive::Tar' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Archive-Tar-1.90.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Archive-Tar-1.92.tar.gz',
         'FILES'        => q[cpan/Archive-Tar],
         'EXCLUDED'     => ['Makefile.PL'],
         'UPSTREAM'     => 'cpan',
@@ -232,22 +223,25 @@ use File::Glob qw(:case);
 
     'autodie' => {
         'MAINTAINER'   => 'pjf',
-        'DISTRIBUTION' => 'PJF/autodie-2.13.tar.gz',
+        'DISTRIBUTION' => 'PJF/autodie-2.19.tar.gz',
         'FILES'        => q[cpan/autodie],
         'EXCLUDED'     => [
             qr{^inc/Module/},
-
+            qr{benchmarks},
             # All these tests depend upon external
             # modules that don't exist when we're
             # building the core.  Hence, they can
             # never run, and should not be merged.
             qw( t/boilerplate.t
+                t/author-critic.t
                 t/critic.t
                 t/fork.t
                 t/kwalitee.t
                 t/lex58.t
                 t/pod-coverage.t
                 t/pod.t
+                t/release-pod-coverage.t
+                t/release-pod-syntax.t
                 t/socket.t
                 t/system.t
                 )
@@ -302,15 +296,6 @@ use File::Glob qw(:case);
         'UPSTREAM'   => 'blead',
     },
 
-    'B::Lint' => {
-        'MAINTAINER'   => 'jjore',
-        'DISTRIBUTION' => 'RJBS/B-Lint-1.17.tar.gz',
-        'FILES'        => q[cpan/B-Lint],
-        'EXCLUDED'     => ['t/test.pl'],
-        'UPSTREAM'     => 'cpan',
-        'DEPRECATED'   => '5.017009',
-    },
-
     'base' => {
         'MAINTAINER'   => 'rgarcia',
         'DISTRIBUTION' => 'RGARCIA/base-2.18.tar.gz',
@@ -366,7 +351,7 @@ use File::Glob qw(:case);
 
     'Compress::Raw::Bzip2' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.060.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.061.tar.gz',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -377,7 +362,7 @@ use File::Glob qw(:case);
 
     'Compress::Raw::Zlib' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.060.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.061.tar.gz',
 
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
@@ -391,7 +376,7 @@ use File::Glob qw(:case);
 
     'Config::Perl::V' => {
         'MAINTAINER'   => 'hmbrand',
-        'DISTRIBUTION' => 'HMBRAND/Config-Perl-V-0.17.tgz',
+        'DISTRIBUTION' => 'HMBRAND/Config-Perl-V-0.18.tgz',
         'FILES'        => q[cpan/Config-Perl-V],
         'EXCLUDED'     => ['examples/show-v.pl'],
         'UPSTREAM'     => 'cpan',
@@ -461,49 +446,13 @@ use File::Glob qw(:case);
         'UPSTREAM' => 'cpan',
     },
 
-    'CPANPLUS' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/CPANPLUS-0.9134.tar.gz',
-        'FILES'        => q[cpan/CPANPLUS],
-        'EXCLUDED'     => [
-            qr{^inc/},
-            qr{^t/dummy-.*\.hidden$},
-            qr{^t/dummy-(cpanplus|perl|localmirror)/},
-            'bin/cpanp-boxed',
-
-            # SQLite tests would be skipped in core, and
-            # the filenames are too long for VMS!
-            qw( t/031_CPANPLUS-Internals-Source-SQLite.t
-                t/032_CPANPLUS-Internals-Source-via-sqlite.t
-                ),
-            'Makefile.PL',
-        ],
-        'CUSTOMIZED' => ['Makefile.PL'],
-        'UPSTREAM'   => 'cpan',
-        'BUGS'       => 'bug-cpanplus@rt.cpan.org',
-        'DEPRECATED' => '5.017009',
-    },
-
-    'CPANPLUS::Dist::Build' => {
-        'MAINTAINER'   => 'bingos',
-        'DISTRIBUTION' => 'BINGOS/CPANPLUS-Dist-Build-0.70.tar.gz',
-        'FILES'        => q[cpan/CPANPLUS-Dist-Build],
-        'EXCLUDED'     => [
-            qr{^inc/},
-            qw( t/99_pod.t
-                t/99_pod_coverage.t
-                ),
-        ],
-        'UPSTREAM' => 'cpan',
-        'DEPRECATED' => '5.017009',
-    },
-
     'CPAN::Meta' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-2.120921.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-2.131560.tar.gz',
         'FILES'        => q[cpan/CPAN-Meta],
         'EXCLUDED'     => [
             qw(t/00-compile.t),
+            qw[t/00-report-prereqs.t],
             qr{^xt},
             qr{^history},
         ],
@@ -543,7 +492,7 @@ use File::Glob qw(:case);
 
     'DB_File' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/DB_File-1.827.tar.gz',
+        'DISTRIBUTION' => 'PMQS/DB_File-1.828.tar.gz',
         'FILES'        => q[cpan/DB_File],
         'EXCLUDED'     => [
             qr{^patches/},
@@ -580,7 +529,7 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'MHX/Devel-PPPort-3.20.tar.gz',
         'FILES'        => q[cpan/Devel-PPPort],
         'EXCLUDED' => ['PPPort.pm'],    # we use PPPort_pm.PL instead
-        'UPSTREAM' => 'cpan',
+        'UPSTREAM' => 'undef', # rjbs has asked mhx to have blead be upstream
     },
 
     'diagnostics' => {
@@ -640,7 +589,7 @@ use File::Glob qw(:case);
 
     'Encode' => {
         'MAINTAINER'   => 'dankogai',
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.49.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.51.tar.gz',
         'FILES'        => q[cpan/Encode],
         'UPSTREAM'     => 'cpan',
     },
@@ -751,7 +700,7 @@ use File::Glob qw(:case);
 
     'ExtUtils::MakeMaker' => {
         'MAINTAINER'   => 'mschwern',
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-6.66.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-6.68.tar.gz',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
@@ -780,7 +729,7 @@ use File::Glob qw(:case);
 
     'perlfaq' => {
         'MAINTAINER'   => 'perlfaq',
-        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150042.tar.gz',
+        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150043.tar.gz',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [
             qw( t/release-pod-syntax.t
@@ -809,14 +758,6 @@ use File::Glob qw(:case);
         'UPSTREAM'   => 'blead',
     },
 
-    'File::CheckTree' => {
-        'MAINTAINER'   => 'p5p',
-        'DISTRIBUTION' => 'RJBS/File-CheckTree-4.42.tar.gz',
-        'FILES'        => q[cpan/File-CheckTree],
-        'EXCLUDED'     => [qr{^t/release-.*\.t}],
-        'UPSTREAM'     => 'cpan',
-    },
-
     'File::DosGlob' => {
         'MAINTAINER' => 'p5p',
         'FILES'      => q[ext/File-DosGlob],
@@ -825,7 +766,7 @@ use File::Glob qw(:case);
 
     'File::Fetch' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/File-Fetch-0.38.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/File-Fetch-0.42.tar.gz',
         'FILES'        => q[cpan/File-Fetch],
         'UPSTREAM'     => 'cpan',
     },
@@ -866,12 +807,15 @@ use File::Glob qw(:case);
 
     'File::Temp' => {
         'MAINTAINER'   => 'tjenness',
-        'DISTRIBUTION' => 'TJENNESS/File-Temp-0.23.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/File-Temp-0.2301.tar.gz',
         'FILES'        => q[cpan/File-Temp],
         'EXCLUDED'     => [
             qw( misc/benchmark.pl
                 misc/results.txt
                 ),
+            qw(t/00-compile.t),
+            qw[t/00-report-prereqs.t],
+            qr{^xt},
         ],
         'UPSTREAM' => 'cpan',
     },
@@ -901,7 +845,7 @@ use File::Glob qw(:case);
 
     'Filter::Util::Call' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'RURBAN/Filter-1.45.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/Filter-1.49.tar.gz',
         'FILES'        => q[cpan/Filter-Util-Call
                  pod/perlfilter.pod
                 ],
@@ -953,7 +897,7 @@ use File::Glob qw(:case);
 
     'Getopt::Long' => {
         'MAINTAINER'   => 'jv',
-        'DISTRIBUTION' => 'JV/Getopt-Long-2.39.tar.gz',
+        'DISTRIBUTION' => 'JV/Getopt-Long-2.40.tar.gz',
         'FILES'        => q[cpan/Getopt-Long],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -985,7 +929,7 @@ use File::Glob qw(:case);
 
     'HTTP::Tiny' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.025.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.031.tar.gz',
         'FILES'        => q[cpan/HTTP-Tiny],
         'EXCLUDED'     => [
             't/00-report-prereqs.t',
@@ -1039,7 +983,7 @@ use File::Glob qw(:case);
 
     'IO-Compress' => {
         'MAINTAINER'   => 'pmqs',
-        'DISTRIBUTION' => 'PMQS/IO-Compress-2.060.tar.gz',
+        'DISTRIBUTION' => 'PMQS/IO-Compress-2.061.tar.gz',
         'FILES'        => q[cpan/IO-Compress],
         'EXCLUDED'     => [qr{t/Test/}],
         'UPSTREAM'     => 'cpan',
@@ -1115,7 +1059,7 @@ use File::Glob qw(:case);
 
     'Locale-Codes' => {
         'MAINTAINER'   => 'sbeck',
-        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.25.tar.gz',
+        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.26.tar.gz',
         'FILES'        => q[cpan/Locale-Codes],
         'EXCLUDED'     => [
             qw( t/pod_coverage.t
@@ -1150,22 +1094,6 @@ use File::Glob qw(:case);
         'UPSTREAM'     => 'cpan',
     },
 
-    'Log::Message' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Log-Message-0.06.tar.gz',
-        'FILES'        => q[cpan/Log-Message],
-        'UPSTREAM'     => 'cpan',
-        'DEPRECATED'   => '5.017009',
-    },
-
-    'Log::Message::Simple' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Log-Message-Simple-0.10.tar.gz',
-        'FILES'        => q[cpan/Log-Message-Simple],
-        'UPSTREAM'     => 'cpan',
-        'DEPRECATED'   => '5.017009',
-    },
-
     'mad' => {
         'MAINTAINER' => 'lwall',
         'FILES'      => q[mad],
@@ -1263,7 +1191,7 @@ use File::Glob qw(:case);
 
     'Module::Build' => {
         'MAINTAINER'   => 'kwilliams',
-        'DISTRIBUTION' => 'LEONT/Module-Build-0.4003.tar.gz',
+        'DISTRIBUTION' => 'LEONT/Module-Build-0.4005.tar.gz',
         'FILES'        => q[cpan/Module-Build],
         'EXCLUDED'     => [
             qw( t/par.t
@@ -1278,7 +1206,7 @@ use File::Glob qw(:case);
 
     'Module::CoreList' => {
         'MAINTAINER'   => 'bingos',
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.85.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.91.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
         'UPSTREAM'     => 'blead',
     },
@@ -1306,7 +1234,7 @@ use File::Glob qw(:case);
 
     'Module::Metadata' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'APEIRON/Module-Metadata-1.000011.tar.gz',
+        'DISTRIBUTION' => 'BOBTFISH/Module-Metadata-1.000014.tar.gz',
         'FILES'        => q[cpan/Module-Metadata],
         'EXCLUDED'     => [
             qr{^maint},
@@ -1315,15 +1243,6 @@ use File::Glob qw(:case);
         'UPSTREAM' => 'cpan',
     },
 
-    'Module::Pluggable' => {
-        'MAINTAINER'   => 'simonw',
-        'DISTRIBUTION' => 'SIMONW/Module-Pluggable-4.7.tar.gz',
-        'FILES'        => q[cpan/Module-Pluggable],
-        'UPSTREAM'     => 'cpan',
-        'CUSTOMIZED'   => ['Makefile.PL'],
-        'DEPRECATED'   => '5.017009',
-    },
-
     'mro' => {
         'MAINTAINER' => 'p5p',
         'FILES'      => q[ext/mro],
@@ -1355,14 +1274,6 @@ use File::Glob qw(:case);
         'UPSTREAM'     => 'cpan',
     },
 
-    'Object::Accessor' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Object-Accessor-0.46.tar.gz',
-        'FILES'        => q[cpan/Object-Accessor],
-        'UPSTREAM'     => 'cpan',
-        'DEPRECATED'   => '5.017009',
-    },
-
     'ODBM_File' => {
         'MAINTAINER' => 'p5p',
         'FILES'      => q[ext/ODBM_File],
@@ -1543,25 +1454,16 @@ use File::Glob qw(:case);
         'UPSTREAM'   => 'blead',
     },
 
-    'Pod::LaTeX' => {
-        'MAINTAINER'   => 'tjenness',
-        'DISTRIBUTION' => 'TJENNESS/Pod-LaTeX-0.61.tar.gz',
-        'FILES'        => q[cpan/Pod-LaTeX],
-        'EXCLUDED'     => ['t/require.t'],
-        'UPSTREAM'     => undef,
-        'DEPRECATED'   => '5.017008',
-    },
-
     'Pod::Parser' => {
         'MAINTAINER' => 'marekr',
-        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.60.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.61.tar.gz',
         'FILES'        => q[cpan/Pod-Parser],
         'UPSTREAM'     => 'cpan',
     },
 
     'Pod::Perldoc' => {
         'MAINTAINER'   => 'mallen',
-        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.19.tar.gz',
+        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.20.tar.gz',
         'FILES'        => q[cpan/Pod-Perldoc],
 
         # in blead, the perldoc executable is generated by perldoc.PL
@@ -1581,7 +1483,7 @@ use File::Glob qw(:case);
 
     'Pod::Usage' => {
         'MAINTAINER' => 'marekr',
-        'DISTRIBUTION' => 'MAREKR/Pod-Usage-1.61.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Usage-1.63.tar.gz',
         'FILES'        => q[cpan/Pod-Usage],
         'UPSTREAM'     => 'cpan',
     },
@@ -1695,7 +1597,7 @@ use File::Glob qw(:case);
 
     'Sys::Syslog' => {
         'MAINTAINER'   => 'saper',
-        'DISTRIBUTION' => 'SAPER/Sys-Syslog-0.32.tar.gz',
+        'DISTRIBUTION' => 'SAPER/Sys-Syslog-0.33.tar.gz',
         'FILES'        => q[cpan/Sys-Syslog],
         'EXCLUDED'     => [
             qr{^eg/},
@@ -1755,14 +1657,6 @@ use File::Glob qw(:case);
         'UPSTREAM'     => 'blead',
     },
 
-    'Term::UI' => {
-        'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/Term-UI-0.34.tar.gz',
-        'FILES'        => q[cpan/Term-UI],
-        'UPSTREAM'     => 'cpan',
-        'DEPRECATED'   => '5.017009',
-    },
-
     'Test' => {
         'MAINTAINER'   => 'jesse',
         'DISTRIBUTION' => 'JESSE/Test-1.26.tar.gz',
@@ -1772,7 +1666,7 @@ use File::Glob qw(:case);
 
     'Test::Harness' => {
         'MAINTAINER'   => 'andya',
-        'DISTRIBUTION' => 'OVID/Test-Harness-3.26.tar.gz',
+        'DISTRIBUTION' => 'OVID/Test-Harness-3.28.tar.gz',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1804,6 +1698,9 @@ use File::Glob qw(:case);
                 lib/Test/Builder/IO/Scalar.pm
                 ),
         ],
+        'CUSTOMIZED' =>  [
+            't/fail-more.t', # awaiting upstream fix
+        ],
         'UPSTREAM' => 'cpan',
     },
 
@@ -1854,24 +1751,9 @@ use File::Glob qw(:case);
         'UPSTREAM' => undef,
     },
 
-    'Text::Soundex' => {
-        'MAINTAINER'   => 'markm',
-        'DISTRIBUTION' => 'RJBS/Text-Soundex-3.04.tar.gz',
-        'FILES'        => q[cpan/Text-Soundex],
-        'MAP'          => {
-            '' => 'cpan/Text-Soundex/',
-
-            # XXX these two files are clearly related,
-            # but they appear to have diverged
-            # considerably over the years
-            'test.pl' => 'cpan/Text-Soundex/t/Soundex.t',
-        },
-        'UPSTREAM' => undef,
-    },
-
     'Text-Tabs+Wrap' => {
         'MAINTAINER'   => 'muir',
-        'DISTRIBUTION' => 'MUIR/modules/Text-Tabs+Wrap-2012.0818.tar.gz',
+        'DISTRIBUTION' => 'MUIR/modules/Text-Tabs+Wrap-2013.0523.tar.gz',
         'FILES'        => q[cpan/Text-Tabs],
         'EXCLUDED'   => [
             qr/^lib\.old/,
@@ -1915,7 +1797,7 @@ use File::Glob qw(:case);
 
     'threads' => {
         'MAINTAINER'   => 'jdhedden',
-        'DISTRIBUTION' => 'JDHEDDEN/threads-1.86.tar.gz',
+        'DISTRIBUTION' => 'JDHEDDEN/threads-1.87.tar.gz',
         'FILES'        => q[dist/threads],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1977,6 +1859,9 @@ use File::Glob qw(:case);
         'MAINTAINER'   => 'zefram',
         'DISTRIBUTION' => 'ZEFRAM/Time-HiRes-1.9725.tar.gz',
         'FILES'        => q[cpan/Time-HiRes],
+        'CUSTOMIZED'   => [
+            'Makefile.PL', # awaiting patches applied upstream (see c7627e6d)
+        ],
         'UPSTREAM'     => 'cpan',
     },
 
@@ -2002,7 +1887,7 @@ use File::Glob qw(:case);
 
     'Unicode::Collate' => {
         'MAINTAINER'   => 'sadahiro',
-        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-0.97.tar.gz',
+        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-0.98.tar.gz',
         'FILES'        => q[cpan/Unicode-Collate],
         'EXCLUDED'     => [
             qr{N$},
