@@ -1,7 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-our $VERSION = '6.61_01';
+our $VERSION = '6.68';
 
 use Carp;
 use File::Spec;
@@ -206,25 +206,40 @@ sub _expand_macros {
 
     my @commands = $MM->echo($text);
     my @commands = $MM->echo($text, $file);
-    my @commands = $MM->echo($text, $file, $appending);
+    my @commands = $MM->echo($text, $file, \%opts);
 
 Generates a set of @commands which print the $text to a $file.
 
 If $file is not given, output goes to STDOUT.
 
-If $appending is true the $file will be appended to rather than
-overwritten.
+If $opts{append} is true the $file will be appended to rather than
+overwritten.  Default is to overwrite.
+
+If $opts{allow_variables} is true, make variables of the form
+C<$(...)> will not be escaped.  Other C<$> will.  Default is to escape
+all C<$>.
+
+Example of use:
+
+    my $make = map "\t$_\n", $MM->echo($text, $file);
 
 =cut
 
 sub echo {
-    my($self, $text, $file, $appending) = @_;
-    $appending ||= 0;
+    my($self, $text, $file, $opts) = @_;
 
-    my @cmds = map { '$(NOECHO) $(ECHO) '.$self->quote_literal($_) } 
+    # Compatibility with old options
+    if( !ref $opts ) {
+        my $append = $opts;
+        $opts = { append => $append || 0 };
+    }
+    $opts->{allow_variables} = 0 unless defined $opts->{allow_variables};
+
+    my $ql_opts = { allow_variables => $opts->{allow_variables} };
+    my @cmds = map { '$(NOECHO) $(ECHO) '.$self->quote_literal($_, $ql_opts) } 
                split /\n/, $text;
     if( $file ) {
-        my $redirect = $appending ? '>>' : '>';
+        my $redirect = $opts->{append} ? '>>' : '>';
         $cmds[0] .= " $redirect $file";
         $_ .= " >> $file" foreach @cmds[1..$#cmds];
     }
@@ -334,12 +349,54 @@ to include more flexible code and switches.
 =head3 quote_literal  I<Abstract>
 
     my $safe_text = $MM->quote_literal($text);
+    my $safe_text = $MM->quote_literal($text, \%options);
 
 This will quote $text so it is interpreted literally in the shell.
 
 For example, on Unix this would escape any single-quotes in $text and
 put single-quotes around the whole thing.
 
+If $options{allow_variables} is true it will leave C<'$(FOO)'> make
+variables untouched.  If false they will be escaped like any other
+C<$>.  Defaults to true.
+
+=head3 escape_dollarsigns
+
+    my $escaped_text = $MM->escape_dollarsigns($text);
+
+Escapes stray C<$> so they are not interpreted as make variables.
+
+It lets by C<$(...)>.
+
+=cut
+
+sub escape_dollarsigns {
+    my($self, $text) = @_;
+
+    # Escape dollar signs which are not starting a variable
+    $text =~ s{\$ (?!\() }{\$\$}gx;
+
+    return $text;
+}
+
+
+=head3 escape_all_dollarsigns
+
+    my $escaped_text = $MM->escape_all_dollarsigns($text);
+
+Escapes all C<$> so they are not interpreted as make variables.
+
+=cut
+
+sub escape_all_dollarsigns {
+    my($self, $text) = @_;
+
+    # Escape dollar signs
+    $text =~ s{\$}{\$\$}gx;
+
+    return $text;
+}
+
 
 =head3 escape_newlines  I<Abstract>
 
@@ -474,10 +531,10 @@ clean :: clean_subdirs
 #     push @dirs, qw($(INST_ARCHLIB) $(INST_LIB)
 #                    $(INST_BIN) $(INST_SCRIPT)
 #                    $(INST_MAN1DIR) $(INST_MAN3DIR)
-#                    $(INST_LIBDIR) $(INST_ARCHLIBDIR) $(INST_AUTODIR) 
+#                    $(INST_LIBDIR) $(INST_ARCHLIBDIR) $(INST_AUTODIR)
 #                    $(INST_STATIC) $(INST_DYNAMIC) $(INST_BOOT)
 #                 );
-                  
+
 
     if( $attribs{FILES} ) {
         # Use @dirs because we don't know what's in here.
@@ -486,7 +543,7 @@ clean :: clean_subdirs
                         split /\s+/, $attribs{FILES}   ;
     }
 
-    push(@files, qw[$(MAKE_APERL_FILE) 
+    push(@files, qw[$(MAKE_APERL_FILE)
                     MYMETA.json MYMETA.yml perlmain.c tmon.out mon.out so_locations
                     blibdirs.ts pm_to_blib pm_to_blib.ts
                     *$(OBJ_EXT) *$(LIB_EXT) perl.exe perl perl$(EXE_EXT)
@@ -499,7 +556,13 @@ clean :: clean_subdirs
     push(@files, $self->catfile('$(INST_ARCHAUTODIR)','extralibs.ld'));
 
     # core files
-    push(@files, qw[core core.*perl.*.? *perl.core]);
+    if ($^O eq 'vos') {
+        push(@files, qw[perl*.kp]);
+    }
+    else {
+        push(@files, qw[core core.*perl.*.? *perl.core]);
+    }
+
     push(@files, map { "core." . "[0-9]"x$_ } (1..5));
 
     # OS specific things to clean up.  Use @dirs since we don't know
@@ -568,7 +631,7 @@ Because depending on a directory to just ensure it exists doesn't work
 too well (the modified time changes too often) dir_target() creates a
 .exists file in the created directory.  It is this you should depend on.
 For portability purposes you should use the $(DIRFILESEP) macro rather
-than a '/' to seperate the directory from the file.
+than a '/' to separate the directory from the file.
 
     yourdirectory$(DIRFILESEP).exists
 
@@ -626,7 +689,7 @@ MAKE_FRAG
 =head3 dist_test
 
 Defines a target that produces the distribution in the
-scratchdirectory, and runs 'perl Makefile.PL; make ;make test' in that
+scratch directory, and runs 'perl Makefile.PL; make ;make test' in that
 subdirectory.
 
 =cut
@@ -942,7 +1005,13 @@ sub metafile_data {
         };
     }
 
-    %meta = $self->_add_requirements_to_meta( %meta );
+    {
+      my $vers = _metaspec_version( $meta_add, $meta_merge );
+      my $method = $vers =~ m!^2!
+               ? '_add_requirements_to_meta_v2'
+               : '_add_requirements_to_meta_v1_4';
+      %meta = $self->$method( %meta );
+    }
 
     while( my($key, $val) = each %$meta_add ) {
         $meta{$key} = $val;
@@ -960,12 +1029,22 @@ sub metafile_data {
 
 =cut
 
-sub _add_requirements_to_meta {
+sub _metaspec_version {
+  my ( $meta_add, $meta_merge ) = @_;
+  return $meta_add->{'meta-spec'}->{version}
+    if defined $meta_add->{'meta-spec'}
+       and defined $meta_add->{'meta-spec'}->{version};
+  return $meta_merge->{'meta-spec'}->{version}
+    if defined $meta_merge->{'meta-spec'}
+       and  defined $meta_merge->{'meta-spec'}->{version};
+  return '1.4';
+}
+
+sub _add_requirements_to_meta_v1_4 {
     my ( $self, %meta ) = @_;
 
     # Check the original args so we can tell between the user setting it
     # to an empty hash and it just being initialized.
-
     if( $self->{ARGS}{BUILD_REQUIRES} ) {
         $meta{build_requires} = _normalize_prereqs($self->{BUILD_REQUIRES});
     } else {
@@ -974,6 +1053,13 @@ sub _add_requirements_to_meta {
         };
     }
 
+    if( $self->{ARGS}{TEST_REQUIRES} ) {
+        $meta{build_requires} = {
+          %{ $meta{build_requires} },
+          %{ _normalize_prereqs($self->{TEST_REQUIRES}) },
+        };
+    }
+
     $meta{requires} = _normalize_prereqs($self->{PREREQ_PM})
         if defined $self->{PREREQ_PM};
     $meta{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
@@ -982,6 +1068,31 @@ sub _add_requirements_to_meta {
     return %meta;
 }
 
+sub _add_requirements_to_meta_v2 {
+    my ( $self, %meta ) = @_;
+
+    # Check the original args so we can tell between the user setting it
+    # to an empty hash and it just being initialized.
+    if( $self->{ARGS}{BUILD_REQUIRES} ) {
+        $meta{prereqs}{build}{requires} = _normalize_prereqs($self->{BUILD_REQUIRES});
+    } else {
+        $meta{prereqs}{build}{requires} = {
+            'ExtUtils::MakeMaker'       => 0,
+        };
+    }
+
+    if( $self->{ARGS}{TEST_REQUIRES} ) {
+        $meta{prereqs}{test}{requires} = _normalize_prereqs($self->{TEST_REQUIRES});
+    }
+
+    $meta{prereqs}{runtime}{requires} = _normalize_prereqs($self->{PREREQ_PM})
+        if defined $self->{PREREQ_PM};
+    $meta{prereqs}{runtime}{requires}{perl} = _normalize_version($self->{MIN_PERL_VERSION})
+        if $self->{MIN_PERL_VERSION};
+
+    return %meta;
+}
+
 sub _normalize_prereqs {
   my ($hash) = @_;
   my %prereqs;
@@ -1205,6 +1316,7 @@ sub mymeta {
     my $file = shift || ''; # for testing
 
     my $mymeta = $self->_mymeta_from_meta($file);
+    my $v2 = 1;
 
     unless ( $mymeta ) {
         my @metadata = $self->metafile_data(
@@ -1212,11 +1324,16 @@ sub mymeta {
             $self->{META_MERGE} || {},
         );
         $mymeta = {@metadata};
+        $v2 = 0;
     }
 
     # Overwrite the non-configure dependency hashes
 
-    $mymeta = { $self->_add_requirements_to_meta( %$mymeta ) };
+    my $method = $v2
+               ? '_add_requirements_to_meta_v2'
+               : '_add_requirements_to_meta_v1_4';
+
+    $mymeta = { $self->$method( %$mymeta ) };
 
     $mymeta->{dynamic_config} = 0;
 
@@ -1234,12 +1351,12 @@ sub _mymeta_from_meta {
     for my $file ( $metafile, "META.json", "META.yml" ) {
       next unless -e $file;
       eval {
-          $meta = CPAN::Meta->load_file($file)->as_struct( {version => "1.4"} );
+          $meta = CPAN::Meta->load_file($file)->as_struct( { version => 2 } );
       };
       last if $meta;
     }
-    return undef unless $meta;
-    
+    return unless $meta;
+
     # META.yml before 6.25_01 cannot be trusted.  META.yml lived in the source directory.
     # There was a good chance the author accidentally uploaded a stale META.yml if they
     # rolled their own tarball rather than using "make dist".
@@ -1247,7 +1364,7 @@ sub _mymeta_from_meta {
         $meta->{generated_by} =~ /ExtUtils::MakeMaker version ([\d\._]+)/) {
         my $eummv = do { local $^W = 0; $1+0; };
         if ($eummv < 6.2501) {
-            return undef;
+            return;
         }
     }
 
@@ -1754,7 +1871,7 @@ sub init_INSTALL_from_PREFIX {
         my($s, $t, $d, $style) = @{$layout}{qw(s t d style)};
         my $r = '$('.$type2prefix{$t}.')';
 
-        print STDERR "Prefixing $var\n" if $Verbose >= 2;
+        warn "Prefixing $var\n" if $Verbose >= 2;
 
         my $installvar = "install$var";
         my $Installvar = uc $installvar;
@@ -1763,7 +1880,7 @@ sub init_INSTALL_from_PREFIX {
         $d = "$style/$d" if $style;
         $self->prefixify($installvar, $s, $r, $d);
 
-        print STDERR "  $Installvar == $self->{$Installvar}\n" 
+        warn "  $Installvar == $self->{$Installvar}\n" 
           if $Verbose >= 2;
     }
 
@@ -1883,7 +2000,7 @@ sub init_VERSION {
 
     # Graham Barr and Paul Marquess had some ideas how to ensure
     # version compatibility between the *.pm file and the
-    # corresponding *.xs file. The bottomline was, that we need an
+    # corresponding *.xs file. The bottom line was, that we need an
     # XS_VERSION macro that defaults to VERSION:
     $self->{XS_VERSION} ||= $self->{VERSION};
 
@@ -1893,15 +2010,14 @@ sub init_VERSION {
 }
 
 
-=head3 init_others
+=head3 init_tools
 
-    $MM->init_others();
+    $MM->init_tools();
 
-Initializes the macro definitions used by tools_other() and places them
-in the $MM object.
-
-If there is no description, its the same as the parameter to
-WriteMakefile() documented in ExtUtils::MakeMaker.
+Initializes the simple macro definitions used by tools_other() and
+places them in the $MM object.  These use conservative cross platform
+versions and should be overridden with platform specific versions for
+performance.
 
 Defines at least these macros.
 
@@ -1910,11 +2026,6 @@ Defines at least these macros.
   NOOP              Do nothing
   NOECHO            Tell make not to display the command itself
 
-  MAKEFILE
-  FIRST_MAKEFILE
-  MAKEFILE_OLD
-  MAKE_APERL_FILE   File used by MAKE_APERL
-
   SHELL             Program used to run shell commands
 
   ECHO              Print text adding a newline on the end
@@ -1933,7 +2044,7 @@ Defines at least these macros.
 
 =cut
 
-sub init_others {
+sub init_tools {
     my $self = shift;
 
     $self->{ECHO}     ||= $self->oneliner('print qq{@ARGV}', ['-l']);
@@ -1966,6 +2077,18 @@ CODE
     $self->{UNINST}     ||= 0;
     $self->{VERBINST}   ||= 0;
 
+    $self->{SHELL}              ||= $Config{sh};
+
+    # UMASK_NULL is not used by MakeMaker but some CPAN modules
+    # make use of it.
+    $self->{UMASK_NULL}         ||= "umask 0";
+
+    # Not the greatest default, but its something.
+    $self->{DEV_NULL}           ||= "> /dev/null 2>&1";
+
+    $self->{NOOP}               ||= '$(TRUE)';
+    $self->{NOECHO}             = '@' unless defined $self->{NOECHO};
+
     $self->{FIRST_MAKEFILE}     ||= $self->{MAKEFILE} || 'Makefile';
     $self->{MAKEFILE}           ||= $self->{FIRST_MAKEFILE};
     $self->{MAKEFILE_OLD}       ||= $self->{MAKEFILE}.'.old';
@@ -1979,17 +2102,24 @@ CODE
     $self->{MACROSTART}         ||= '';
     $self->{MACROEND}           ||= '';
 
-    $self->{SHELL}              ||= $Config{sh};
+    return;
+}
 
-    # UMASK_NULL is not used by MakeMaker but some CPAN modules
-    # make use of it.
-    $self->{UMASK_NULL}         ||= "umask 0";
 
-    # Not the greatest default, but its something.
-    $self->{DEV_NULL}           ||= "> /dev/null 2>&1";
+=head3 init_others
 
-    $self->{NOOP}               ||= '$(TRUE)';
-    $self->{NOECHO}             = '@' unless defined $self->{NOECHO};
+    $MM->init_others();
+
+Initializes the macro definitions having to do with compiling and
+linking used by tools_other() and places them in the $MM object.
+
+If there is no description, its the same as the parameter to
+WriteMakefile() documented in ExtUtils::MakeMaker.
+
+=cut
+
+sub init_others {
+    my $self = shift;
 
     $self->{LD_RUN_PATH} = "";
 
@@ -2030,7 +2160,7 @@ CODE
                         : ($Config{usedl} ? 'dynamic' : 'static');
     }
 
-    return 1;
+    return;
 }
 
 
@@ -2087,7 +2217,7 @@ sub tools_other {
   $MM->init_DIRFILESEP;
   my $dirfilesep = $MM->{DIRFILESEP};
 
-Initializes the DIRFILESEP macro which is the seperator between the
+Initializes the DIRFILESEP macro which is the separator between the
 directory and filename in a filepath.  ie. / on Unix, \ on Win32 and
 nothing on VMS.
 
@@ -2099,8 +2229,8 @@ For example:
 Something of a hack but it prevents a lot of code duplication between
 MM_* variants.
 
-Do not use this as a seperator between directories.  Some operating
-systems use different seperators between subdirectories as between
+Do not use this as a separator between directories.  Some operating
+systems use different separators between subdirectories as between
 directories and filenames (for example:  VOLUME:[dir1.dir2]file on VMS).
 
 =head3 init_linker  I<Abstract>
@@ -2129,7 +2259,7 @@ Some OSes do not need these in which case leave it blank.
 
 Initialize any macros which are for platform specific use only.
 
-A typical one is the version number of your OS specific mocule.
+A typical one is the version number of your OS specific module.
 (ie. MM_Unix_VERSION or MM_VMS_VERSION).
 
 =cut
@@ -2202,7 +2332,7 @@ sub POD2MAN_macro {
     my $self = shift;
 
 # Need the trailing '--' so perl stops gobbling arguments and - happens
-# to be an alternative end of line seperator on VMS so we quote it
+# to be an alternative end of line separator on VMS so we quote it
     return <<'END_OF_DEF';
 POD2MAN_EXE = $(PERLRUN) "-MExtUtils::Command::MM" -e pod2man "--"
 POD2MAN = $(POD2MAN_EXE)
@@ -2313,7 +2443,7 @@ sub arch_check {
 
         my $arch = (grep length, $self->splitdir($pthinks))[-1];
 
-        print STDOUT <<END unless $self->{UNINSTALLED_PERL};
+        print <<END unless $self->{UNINSTALLED_PERL};
 Your perl and your Config.pm seem to have different ideas about the 
 architecture they are running on.
 Perl thinks: [$arch]
@@ -2517,6 +2647,66 @@ sub _all_prereqs {
     return { %{$self->{PREREQ_PM}}, %{$self->{BUILD_REQUIRES}} };
 }
 
+=begin private
+
+=head3 _perl_header_files
+
+  my $perl_header_files= $self->_perl_header_files;
+
+returns a sorted list of header files as found in PERL_SRC or $archlibexp/CORE.
+
+Used by perldepend() in MM_Unix and MM_VMS via _perl_header_files_fragment()
+
+=end private
+
+=cut
+
+sub _perl_header_files {
+    my $self = shift;
+
+    my $header_dir = $self->{PERL_SRC} || $self->catdir($Config{archlibexp}, 'CORE');
+    opendir my $dh, $header_dir
+        or die "Failed to opendir '$header_dir' to find header files: $!";
+
+    # we need to use a temporary here as the sort in scalar context would have undefined results.
+    my @perl_headers= sort grep { /\.h\z/ } readdir($dh);
+
+    closedir $dh;
+
+    return @perl_headers;
+}
+
+=begin private
+
+=head3 _perl_header_files_fragment ($o, $separator)
+
+  my $perl_header_files_fragment= $self->_perl_header_files_fragment("/");
+
+return a Makefile fragment which holds the list of perl header files which
+XS code depends on $(PERL_INC), and sets up the dependency for the $(OBJECT) file.
+
+The $separator argument defaults to "". MM_VMS will set it to "" and MM_UNIX to "/"
+in perldepend(). This reason child subclasses need to control this is that in
+VMS the $(PERL_INC) directory will already have delimiters in it, but in
+UNIX $(PERL_INC) will need a slash between it an the filename. Hypothetically
+win32 could use "\\" (but it doesn't need to).
+
+=end private
+
+=cut
+
+sub _perl_header_files_fragment {
+    my ($self, $separator)= @_;
+    $separator ||= "";
+    return join("\\\n",
+                "PERL_HDRS = ",
+                map {
+                    sprintf( "        \$(PERL_INC)%s%s            ", $separator, $_ )
+                } $self->_perl_header_files()
+           ) . "\n\n"
+           . "\$(OBJECT) : \$(PERL_HDRS)\n";
+}
+
 
 =head1 AUTHOR
 
