@@ -1043,10 +1043,10 @@ Perl_gv_fetchmethod_pvn_flags(pTHX_ HV *stash, const char *name, const STRLEN le
 		}
 
 		Perl_croak(aTHX_
-			   "Can't locate object method \"%"SVf"\" via package \"%"SVf"\""
+			   "Can't locate object method \"%"UTF8f
+			   "\" via package \"%"SVf"\""
 			   " (perhaps you forgot to load \"%"SVf"\"?)",
-			   SVfARG(newSVpvn_flags(name, nend - name,
-                                SVs_TEMP | is_utf8)),
+			   is_utf8, nend - name, name,
                            SVfARG(packnamesv), SVfARG(packnamesv));
 	    }
 	}
@@ -1123,8 +1123,7 @@ Perl_gv_autoload_pvn(pTHX_ HV *stash, const char *name, STRLEN len, U32 flags)
 	    packname = sv_2mortal(newSVhek(HvNAME_HEK(stash)));
 	if (flags & GV_SUPER) sv_catpvs(packname, "::SUPER");
     }
-    if (!(gv = gv_fetchmeth_pvn(stash, S_autoload, S_autolen, FALSE,
-				is_utf8 | (flags & GV_SUPER))))
+    if (!(gv = gv_fetchmeth_pvn(stash, S_autoload, S_autolen, FALSE, is_utf8)))
 	return NULL;
     cv = GvCV(gv);
 
@@ -3175,10 +3174,11 @@ Perl_gv_try_downgrade(pTHX_ GV *gv)
 			HEK_LEN(namehek)*(HEK_UTF8(namehek) ? -1 : 1), 0)) &&
 	    *gvp == (SV*)gv) {
 	SV *value = SvREFCNT_inc(CvXSUBANY(cv).any_ptr);
+	const bool imported = !!GvIMPORTED_CV(gv);
 	SvREFCNT(gv) = 0;
 	sv_clear((SV*)gv);
 	SvREFCNT(gv) = 1;
-	SvFLAGS(gv) = SVt_IV|SVf_ROK;
+	SvFLAGS(gv) = SVt_IV|SVf_ROK|SVprv_PCS_IMPORTED * imported;
 	SvANY(gv) = (XPVGV*)((char*)&(gv->sv_u.svu_iv) -
 				STRUCT_OFFSET(XPVIV, xiv_iv));
 	SvRV_set(gv, value);
