@@ -119,10 +119,12 @@ PERLVAR(I, sv_objcount,	IV)		/* DEPRECATED AND UNMAINTAINED.
 PERLVAR(I, sv_root,	SV *)		/* storage for SVs belonging to interp */
 PERLVAR(I, sv_arenaroot, SV *)		/* list of areas for garbage collection */
 
-PERLVAR(I, reg_state,	struct re_save_state)
+/* fake PMOP that PL_curpm points to while in (?{}) so $1 et al are visible */
+PERLVARI(I, reg_curpm, PMOP*, NULL)
 
 /* the currently active slab in a chain of slabs of regmatch states,
- * and the currently active state within that slab */
+ * and the currently active state within that slab. This stack of states
+ * is shared amongst re-entrant calls to the regex engine */
 
 PERLVARI(I, regmatch_slab, regmatch_slab *,	NULL)
 PERLVAR(I, regmatch_state, regmatch_state *)
@@ -226,8 +228,6 @@ PERLVAR(I, secondgv,	GV *)		/* $b */
 PERLVAR(I, efloatbuf,	char *)
 PERLVAR(I, efloatsize,	STRLEN)
 
-PERLVAR(I, regdummy,	regnode)	/* from regcomp.c */
-
 PERLVARI(I, dumpindent,	U16,	4)	/* number of blanks per dump
 					   indentation level */
 
@@ -235,7 +235,7 @@ PERLVAR(I, exit_flags,	U8)		/* was exit() unexpected, etc. */
 
 PERLVAR(I, utf8locale,	bool)		/* utf8 locale detected */
 
-PERLVARA(I, colors,6,	char *)		/* from regcomp.c */
+PERLVARA(I, colors,6,	char *)		/* values from PERL_RE_COLORS env var */
 
 /*
 =for apidoc Amn|peep_t|PL_peepp
@@ -556,7 +556,7 @@ PERLVAR(I, sawampersand, U8)		/* must save all match strings */
 #endif
 
 PERLVAR(I, unsafe,	bool)
-PERLVAR(I, colorset,	bool)		/* from regcomp.c */
+PERLVAR(I, colorset,	bool)		/* PERL_RE_COLORS env var is in use */
 
 /* current phase the interpreter is in
    for ordering this structure to remove holes, we're assuming that this is 4
@@ -741,7 +741,7 @@ PERLVAR(I, debug_pad,	struct perl_debug_pad)	/* always needed because of the re
 /* Hook for File::Glob */
 PERLVARI(I, globhook,	globhook_t, NULL)
 
-/* The last unconditional member of the interpreter structure when 5.19.0 was
+/* The last unconditional member of the interpreter structure when 5.19.1 was
    released. The offset of the end of this is baked into a global variable in 
    any shared perl library which will allow a sanity test in future perl
    releases.  */
