@@ -22,7 +22,7 @@ sub syscopy;
 sub cp;
 sub mv;
 
-$VERSION = '2.25';
+$VERSION = '2.27';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -435,9 +435,9 @@ File::Copy - Copy files or filehandles
 
 	use File::Copy;
 
-	copy("file1","file2") or die "Copy failed: $!";
+	copy("sourcefile","destinationfile") or die "Copy failed: $!";
 	copy("Copy.pm",\*STDOUT);
-	move("/dev1/fileA","/dev2/fileB");
+	move("/dev1/sourcefile","/dev2/destinationfile");
 
 	use File::Copy "cp";
 
@@ -486,7 +486,7 @@ upon the file, but will generally be the whole file (up to 2MB), or
 
 You may use the syntax C<use File::Copy "cp"> to get at the C<cp>
 alias for this function. The syntax is I<exactly> the same.  The
-behavior is nearly the same as well: as of version 2.15, <cp> will
+behavior is nearly the same as well: as of version 2.15, C<cp> will
 preserve the source file's permission bits like the shell utility
 C<cp(1)> would do, while C<copy> uses the default permissions for the
 target file (which may depend on the process' C<umask>, file
@@ -509,7 +509,7 @@ during this copy-and-delete process, you may be left with a (possibly partial)
 copy of the file under the destination name.
 
 You may use the C<mv> alias for this function in the same way that
-you may use the <cp> alias for C<copy>.
+you may use the C<cp> alias for C<copy>.
 
 =item syscopy
 X<syscopy>
