@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# regen.pl - a wrapper that runs all *.pl scripts to to autogenerate files
+# regen.pl - a wrapper that runs all *.pl scripts to autogenerate files
 
 require 5.004;	# keep this compatible, an old perl is all we may have before
                 # we build the new one
@@ -16,13 +16,14 @@ use strict;
 # Which scripts to run.
 
 my @scripts = qw(
-keywords.pl
+mg_vtable.pl
 opcode.pl
 overload.pl
 reentr.pl
 regcomp.pl
 warnings.pl
 embed.pl
+feature.pl
 );
 
 my $tap = $ARGV[0] && $ARGV[0] eq '--tap' ? '# ' : '';
